==> haskell-interpolatedstring-perl6-1.0.1-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolatedstring-perl6
version: 1.0.1
id: interpolatedstring-perl6-1.0.1-KRVFjlGnrsGJOadhodcrGY
key: interpolatedstring-perl6-1.0.1-KRVFjlGnrsGJOadhodcrGY
license: LicenseRef-PublicDomain
copyright: Audrey Tang
maintainer: Audrey Tang <audreyt@audreyt.org>
author: Audrey Tang
stability: stable
synopsis: QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.
category: Data
abi: a3edfecfc71732a46b86f9de01cb1d82
exposed: True
exposed-modules:
    Text.InterpolatedString.Perl6
import-dirs: /usr/lib/ghc-8.6.4/site-local/interpolatedstring-perl6-1.0.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/interpolatedstring-perl6-1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-interpolatedstring-perl6
hs-libraries: HSinterpolatedstring-perl6-1.0.1-KRVFjlGnrsGJOadhodcrGY
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    haskell-src-meta-0.8.2-DkmDe2I29r63MEwAPwJrgz
    template-haskell-2.14.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock
haddock-html: /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-interpolatedstring-perl6-1.0.1-20-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-interpolatedstring-perl6.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: interpolatedstring-perl6
version: 1.0.1
id: interpolatedstring-perl6-1.0.1-1ByxHAoEMeBD0WiihzLurW
key: interpolatedstring-perl6-1.0.1-1ByxHAoEMeBD0WiihzLurW
license: LicenseRef-PublicDomain
copyright: Audrey Tang
maintainer: Audrey Tang <audreyt@audreyt.org>
author: Audrey Tang
stability: stable
synopsis: QuasiQuoter for Perl6-style multi-line interpolated strings
description:
    QuasiQuoter for Perl6-style multi-line interpolated strings with \"q\", \"qq\" and \"qc\" support.
category: Data
abi: 215dc5730fe58c7bd46f5956534c14a5
exposed: True
exposed-modules:
    Text.InterpolatedString.Perl6
import-dirs: /usr/lib/ghc-8.6.4/site-local/interpolatedstring-perl6-1.0.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/interpolatedstring-perl6-1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-interpolatedstring-perl6
hs-libraries: HSinterpolatedstring-perl6-1.0.1-1ByxHAoEMeBD0WiihzLurW
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    haskell-src-meta-0.8.2-8ADbVF5VqZcIuW9XL3cCSz
    template-haskell-2.14.0.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-interpolatedstring-perl6/html/interpolatedstring-perl6.haddock
haddock-html: /usr/share/doc/haskell-interpolatedstring-perl6/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
